<?php

/**
 * Tinkoff Bank Payment package for Concrete CMS Community Store
 *
 * The MIT License (MIT)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @copyright 2021-2022, Alex Borisov
 * @package Concrete\Package\community_store_tinkoff
 */

namespace Concrete\Package\CommunityStoreTinkoff;

use Concrete\Core\Package\Package;
use Concrete\Core\Routing\Router;
use Whoops\Exception\ErrorException;

use Concrete\Package\CommunityStore\Src\CommunityStore\Payment\Method as PaymentMethod;

class Controller extends Package
{
    protected $pkgHandle = 'community_store_tinkoff';
    protected $appVersionRequired = '9.0.0';
    protected $pkgVersion = '0.9.3';
    protected $packageDependencies = ['community_store' => '2.4.3'];
    protected $pkgAutoloaderRegistries = [
        'src/CommunityStore' => '\Concrete\Package\CommunityStoreTinkoff\Src\CommunityStore',
    ];

    public function getPackageDescription()
    {
        return t('Tinkoff Bank Payment Method for Community Store');
    }

    public function getPackageName()
    {
        return t('Tinkoff Bank Payment Method');
    }

    public function on_start() {
        $router = $this->app->make(Router::class);
        $router->register('/checkout/tinkoffresponse', '\Concrete\Package\CommunityStoreTinkoff\Src\CommunityStore\Payment\Methods\CommunityStoreTinkoff\CommunityStoreTinkoffPaymentMethod::validateCompletion', null, [], [], '', [], ['GET']);
        $router->register('/checkout/tinkoffcallback', '\Concrete\Package\CommunityStoreTinkoff\Src\CommunityStore\Payment\Methods\CommunityStoreTinkoff\CommunityStoreTinkoffPaymentMethod::callback', null, [], [], '', [], ['POST']);
        $router->register('/dashboard/store/settings/tinkoffclearlog', '\Concrete\Package\CommunityStoreTinkoff\Src\CommunityStore\Payment\Methods\CommunityStoreTinkoff\CommunityStoreTinkoffPaymentMethod::clearlog', null, [], [], '', [], ['GET']);
    }

    public function install()
    {
        $pkg = parent::install();
        $pm = $this->app->make(PaymentMethod::class);
        $pm->add('community_store_tinkoff','Tinkoff Bank',$pkg);
    }
    public function uninstall()
    {
        $pm = PaymentMethod::getByHandle('community_store_tinkoff');
        
        if ($pm) {
            $pm->delete();
        }
        
        parent::uninstall();
        
        $db = $this->app->make('database')->connection();
        $q = 'DROP TABLE IF EXISTS CommunityStorePaymentTinkoff';
        $v = [''];
        $db->executeQuery($q, $v);
    }

}
?>
